import { Controller, Get, Inject, Query } from '@midwayjs/core';
import { SearchService } from '../service/search.service';
import { Context } from '@midwayjs/koa';
import { omit } from 'lodash';
import { SearchBehaviorService } from '../service/searchBehavior.service';

@Controller('/search')
export class SearchController {
  @Inject()
  searchService: SearchService;
  @Inject()
  ctx: Context;
  @Inject()
  sbService: SearchBehaviorService;

  @Get('/company')
  async company(@Query('keyword') keyword: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const query = this.ctx.query;
    const others = omit(query, ['keyword', 'skip', 'limit']);
    const res = await this.searchService.company(keyword, skip, limit, others);
    // 转至日志库,记录 谁,什么时间.通过什么 内容 进行检索. 形成词云
    try {
      if (keyword && keyword !== '') await this.sbService.makeLogs(keyword);
    } catch (error) {
      console.error(error);
    }
    return res;
  }
  // @Get('/expert')
  // async expert(@Query('keyword') keyword: string, @Query('skip') skip: number, @Query('limit') limit: number) {
  //   const res = await this.searchService.expert(keyword, skip, limit);
  //   return res;
  // }
  @Get('/project')
  async project(@Query('keyword') keyword: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const query = this.ctx.query;
    const others = omit(query, ['keyword', 'skip', 'limit']);
    const res = await this.searchService.project(keyword, skip, limit, others);
    // 转至日志库,记录 谁,什么时间.通过什么 内容 进行检索. 形成词云
    try {
      if (keyword && keyword !== '') await this.sbService.makeLogs(keyword);
    } catch (error) {
      console.error(error);
    }
    return res;
  }

  /**智能匹配也可以使用 */
  @Get('/demand')
  async demand(@Query('keyword') keyword: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const query = this.ctx.query;
    const others = omit(query, ['keyword', 'skip', 'limit']);
    const res = await this.searchService.demand(keyword, skip, limit, others);
    // 转至日志库,记录 谁,什么时间.通过什么 内容 进行检索. 形成词云
    try {
      if (keyword && keyword !== '') await this.sbService.makeLogs(keyword);
    } catch (error) {
      console.error(error);
    }
    return res;
  }
  /**智能匹配也可以使用 */
  @Get('/supply')
  async supply(@Query('keyword') keyword: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const query = this.ctx.query;
    const others = omit(query, ['keyword', 'skip', 'limit']);
    const res = await this.searchService.supply(keyword, skip, limit, others);
    // 转至日志库,记录 谁,什么时间.通过什么 内容 进行检索. 形成词云
    try {
      if (keyword && keyword !== '') await this.sbService.makeLogs(keyword);
    } catch (error) {
      console.error(error);
    }
    return res;
  }
  @Get('/achievement')
  async achievement(@Query('keyword') keyword: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const query = this.ctx.query;
    const others = omit(query, ['keyword', 'skip', 'limit']);
    const res = await this.searchService.achievement(keyword, skip, limit, others);
    // 转至日志库,记录 谁,什么时间.通过什么 内容 进行检索. 形成词云
    try {
      if (keyword && keyword !== '') await this.sbService.makeLogs(keyword);
    } catch (error) {
      console.error(error);
    }
    return res;
  }
}
