import { IMiddleware, Inject, Middleware } from '@midwayjs/core';
import { JwtService } from '@midwayjs/jwt';
import { NextFunction, Context } from '@midwayjs/koa';
import { get } from 'lodash';

@Middleware()
export class CheckTokenMiddleware implements IMiddleware<Context, NextFunction> {
  @Inject()
  jwtService: JwtService;
  resolve() {
    return async (ctx: Context, next: NextFunction) => {
      const token: any = get(ctx.request, 'header.token');
      if (token) {
        const data = this.jwtService.decodeSync(token);
        if (data) ctx.user = data;
      }
      await next();
    };
  }

  static getName(): string {
    return 'checkToken';
  }
}
