import { Client } from '@elastic/elasticsearch';
import { Config, Init, Provide } from '@midwayjs/core';
import { floor, get } from 'lodash';

@Provide()
export class AccurateMatchingService {
  @Config('elasticsearch')
  esConfig: object;
  /**es连接实例 */
  esClient: Client;
  @Init()
  async initClient() {
    const esClient = new Client(this.esConfig);
    this.esClient = esClient;
  }

  async demand(keyword: string, skip: number = 0, limit: number = 10) {
    const config = { index: 'demand', fields: ['name', 'tags', 'area', 'brief'] };
    return this.search(keyword, config, skip, limit);
  }

  async supply(keyword: string, skip: number = 0, limit: number = 10) {
    const config = { index: 'supply', fields: ['name', 'tags', 'area', 'brief'] };
    return this.search(keyword, config, skip, limit);
  }
  async achievement(keyword: string, skip: number = 0, limit: number = 10) {
    const config = { index: 'achievement', fields: ['name', 'tags', 'area', 'brief'] };
    return this.search(keyword, config, skip, limit);
  }

  /**精准匹配统一查询,使用简单的form+size分页模式.如果数据量大于1w,此处的分页模式应该修改,不过就会影响资源的占用及数据的实时性 */
  async search(keyword: string, config: object, skip: number, limit: number) {
    const index = get(config, 'index');
    const fields = get(config, 'fields', []);
    const result = await this.esClient.search({
      index,
      query: {
        bool: {
          must: [
            {
              multi_match: {
                query: keyword,
                fields,
              },
            },
          ],
        },
      },
      size: limit,
      from: skip,
    });
    const returnData = this.dealResponses(result)
    return returnData;
  }

  dealResponses(result) {
    const total = get(result, 'hits.total.value', 0);
    const hits = get(result, 'hits.hits', []);
    const list = [];
    for (const ol of hits) {
      const _score = get(ol, '_score', 0);
      const data = get(ol, '_source', {});
      let recommend = 0;
      /**推荐星数计算:超过5,就都是5颗星.未超过5的都向下取整 */
      if (_score >= 5) recommend = 5;
      else recommend = floor(_score);
      data._recommend = recommend;
      list.push(data);
    }
    return { total, data: list };
  }
}
