import { get } from 'lodash';
const indices = {
  achievement: {
    id: 'number',
    user: 'number',
    industry: 'text',
    tags: 'text',
    patent: 'text',
    name: 'text',
    attribute: 'text',
    sell: 'text',
    num: 'number',
    mature: 'text',
    field: 'text',
    technology: 'text',
    area: 'text',
    time: 'date',
    money: 'text',
    brief: 'text',
    file: 'nested',
    source: 'text',
    person: 'text',
    tel: 'text',
    is_use: 'keyword',
    status: 'keyword',
  },
  demand: {
    id: 'number',
    user: 'number',
    tags: 'text',
    name: 'text',
    type: 'text',
    field: 'text',
    urgent: 'text',
    method: 'text',
    start_time: 'date',
    end_time: 'date',
    money: 'text',
    area: 'text',
    brief: 'text',
    demand_status: 'text',
    industry: 'text',
    company: 'text',
    company_brief: 'text',
    contacts: 'text',
    tel: 'text',
    year: 'text',
    month: 'text',
    tec_name: 'text',
    question: 'text',
    is_use: 'keyword',
    status: 'keyword',
  },
  footplate: {
    id: 'number',
    user: 'number',
    file: 'nested',
    industry: 'text',
    tags: 'text',
    name: 'text',
    build: 'text',
    operate: 'text',
    field: 'text',
    area: 'text',
    address: 'text',
    contacts: 'text',
    phone: 'text',
    brief: 'text',
    is_use: 'keyword',
    status: 'keyword',
  },
  match: {
    id: 'number',
    user: 'number',
    tags: 'text',
    name: 'text',
    type: 'text',
    match_type: 'text',
    scale: 'text',
    href: 'text',
    work: 'text',
    address: 'text',
    industry: 'text',
    form: 'text',
    start_time: 'date',
    end_time: 'date',
    money: 'text',
    rules: 'nested',
    brief: 'text',
    file: 'nested',
    video: 'nested',
    match_status: 'keyword',
    order_num: 'number',
    is_use: 'keyword',
    status: 'keyword',
  },
  project: {
    id: 'number',
    user: 'number',
    tags: 'text',
    name: 'text',
    time: 'date',
    type: 'text',
    maturity: 'text',
    skill: 'text',
    field: 'text',
    cooperate: 'text',
    area: 'text',
    brief: 'text',
    main: 'text',
    progress: 'text',
    track_unit: 'text',
    source: 'text',
    industry: 'text',
    file: 'nested',
    is_use: 'keyword',
    status: 'keyword',
  },
  supply: {
    id: 'number',
    user: 'number',
    name: 'text',
    tags: 'text',
    type: 'text',
    field: 'text',
    urgent: 'text',
    method: 'text',
    start_time: 'date',
    end_time: 'date',
    money: 'text',
    area: 'text',
    brief: 'text',
    demand_status: 'text',
    industry: 'text',
    source: 'text',
    is_use: 'keyword',
    status: 'keyword',
  },
  support: {
    id: 'number',
    user: 'number',
    file: 'nested',
    industry: 'text',
    tags: 'text',
    name: 'text',
    field: 'text',
    time: 'date',
    area: 'text',
    address: 'text',
    contacts: 'text',
    phone: 'text',
    brief: 'text',
    is_use: 'keyword',
    status: 'keyword',
  },
  company: {
    id: 'number',
    user: 'number',
    industry: 'text',
    tags: 'text',
    name: 'text',
    logo: 'nested',
    code: 'text',
    pattern: 'keyword',
    scale: 'keyword',
    phone: 'text',
    type: 'keyword',
    area: 'text',
    representative: 'text',
    email: 'text',
    person: 'number',
    register: 'text',
    create_time: 'date',
    address: 'text',
    brief: 'text',
    companyStatus: 'text',
    products: 'text',
    is_show: 'keyword',
    status: 'keyword',
  },
  expert: {
    id: 'number',
    user: 'number',
    tags: 'text',
    name: 'text',
    icon: 'nested',
    gender: 'keyword',
    birth: 'date',
    cardType: 'keyword',
    card: 'keyword',
    phone: 'text',
    field: 'text',
    direction: 'text',
    work: 'text',
    education: 'keyword',
    title: 'text',
    brief: 'text',
    area: 'text',
    industry_type: 'text',
    work_type: 'text',
    is_show: 'keyword',
    status: 'keyword',
  },
  incubator: {
    id: 'number',
    user: 'number',
    industry: 'text',
    tags: 'text',
    name: 'text',
    person: 'keyword',
    person_phone: 'text',
    area: 'text',
    address: 'text',
    brief: 'text',
    is_show: 'keyword',
    cooperate: 'keyword',
    status: 'keyword',
  },
  school: {
    id: 'number',
    user: 'number',
    name: 'text',
    person: 'keyword',
    person_phone: 'text',
    brief: 'text',
    address: 'text',
    is_show: 'keyword',
    status: 'keyword',
  },
  unit: {
    id: 'number',
    user: 'number',
    name: 'text',
    person: 'keyword',
    person_phone: 'text',
    brief: 'text',
    address: 'text',
    is_show: 'keyword',
    status: 'keyword',
  },
};

const getType = type => {
  const types = {
    text: { type: 'text', analyzer: 'ik_max_word', search_analyzer: 'ik_smart' },
    keyword: { type: 'keyword' },
    number: { type: 'integer' },
    long: { type: 'long' },
    float: { type: 'float' },
    double: { type: 'double' },
    date: {
      type: 'date',
      format: 'yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis',
    },
    boolean: { type: 'boolean' },
    nested: { type: 'nested' },
  };
  return get(types, type);
};
enum Methods {
  CREATE = 'CREATE',
  UPDATE = 'UPDATE',
  DELETE = 'DELETE',
}
export { indices, getType, Methods };
