import { Provide } from '@midwayjs/core';
import { InjectEntityModel } from '@midwayjs/typeorm';
import { Repository } from 'typeorm';
import { BaseServiceV2 } from '../frame/BaseServiceV2';
import { SearchBehavior } from '../entityLogs/searchBehavior.entity';
import { get } from 'lodash';
import dayjs = require('dayjs');
@Provide()
export class SearchBehaviorService extends BaseServiceV2 {
  @InjectEntityModel(SearchBehavior)
  model: Repository<SearchBehavior>;

  async makeLogs(keyword: string) {
    const user = this.ctx.user;
    if (!user) return;
    if (!user.id) return;
    const req = this.ctx.request;
    // 排除管理员查询
    const role = get(user, 'role', []);
    const has_admin = role.find(f => f === 'Admin');
    if (has_admin) return;
    const logInfo: any = {
      operator_id: user.id,
      operator_name: get(user, 'nick_name', get(user, 'name')),
      // ip
      ip: get(req, 'header.x-forwarded-for', req.ip),
      // 设备
      device: get(req, 'header.user-agent'),
      // 操作时间
      time: dayjs().format('YYYY-MM-DD HH:mm:ss'),
      keyword,
    };
    await this.model.insert(logInfo);
  }
}
